==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/hu.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Feladatok",
    "Due yesterday" : "Tegnapi teendök",
    "Due today" : "Mai teendök",
    "Due tomorrow" : "Holnapi teendök",
    "Due on" : "Esedékes",
    "Started yesterday" : "Megkezdve tegnap",
    "Starts today" : "Kezdés ma",
    "Starts tomorrow" : "Kezdés holnap",
    "Started on" : "Megkezdve",
    "Starts on" : "Kezdödik",
    "[Remind me yesterday at ]HH:mm" : "[Emlékeztess holnap ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Emlékeztess ma ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Emlékeztess holnap ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Emlékeztess ]MMM DD, YYYY,HH:mm[ kor ]",
    "Yesterday" : "Tegnap",
    "Today" : "Ma",
    "Tomorrow" : "Holnap",
    "in %s" : "itt:  %s",
    "%s ago" : "%s ezelött",
    "seconds" : "másodperc",
    "a minute" : "egy perc",
    "%d minutes" : "%d perc",
    "an hour" : "óra",
    "%d hours" : "%d óra",
    "a day" : "Nap",
    "%d days" : "%d nap",
    "a month" : "egy hónap",
    "%d months" : "%d hónap",
    "a year" : "egy év",
    "%d years" : "%d év",
    "week" : "hét",
    "weeks" : "hetek",
    "day" : "nap",
    "days" : "nap",
    "hour" : "óra",
    "hours" : "óra",
    "minute" : "perc",
    "minutes" : "perc",
    "second" : "másodperc",
    "before beginning" : "kezdés elött",
    "after beginning" : "kezdés után",
    "before end" : "Befejezés elött",
    "after end" : "Befejezés után",
    "Comment" : "Komment",
    "Add a comment" : "Komment hozzáadása",
    "This will delete the Calendar \"%s\" and all of its entries." : "Ez törölni fogja a Naptárat \"%s\" és az összes bejegyzést.",
    "The name \"%s\" is already used." : "Ez a név \"%s\" már foglalt.",
    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
    "Hidden" : "Rejtett",
    "Visible" : "Látható",
    "Automatic" : "Autómatikus",
    "Sunday" : "vasárnap",
    "Monday" : "hétfő",
    "Tuesday" : "kedd",
    "Wednesday" : "szerda",
    "Thursday" : "csütörtök",
    "Friday" : "péntek",
    "Saturday" : "szombat",
    "Add an important item in \"%s\"..." : "Fontos elem hozzáadása ebben: %s...",
    "Add an item due today in \"%s\"..." : "Elem hozzáadása ma ebben: %s...",
    "Add an item in \"%s\"..." : "Elem hozzáadása ebben: %s...",
    "Add a current item in \"%s\"..." : "Jelenlegi elem hozzáadása ebben: %s...",
    "Add a subtask to \"%s\"..." : "Részfeladat hozzáadás ehhez: \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n befejezett feladat","%n befejezett feladat"],
    "Hours" : "Óra",
    "Minutes" : "Perc",
    "Set due date" : "Lejárati dátum beállítása",
    "%s %% completed" : "%s %% befejezve",
    "priority %s: " : "prioritás %s:",
    "high" : "magas",
    "medium" : "közepes",
    "low" : "alacsony",
    "no priority assigned" : "nincs prioritás beállítva",
    "Remind me" : "Emlékeztess",
    "at the end" : "a végénél",
    "at the beginning" : "az elején",
    "Set start date" : "Kezdő dátum beállítása",
    "{calendar} shared by {owner}" : "{calendar} megosztója: {owner}",
    "Unnamed" : "Névtelen",
    "Important" : "Fontos",
    "Week" : "Hét",
    "All" : "Mind",
    "Current" : "Jelenlegi",
    "Completed" : "Befejezve",
    "Delete" : "Törlés",
    "Cancel" : "Mégsem",
    "Edit" : "Szerkesztés",
    "Link" : "Hivatkozás",
    "Download" : "Letöltés",
    "Save" : "Mentés",
    "Add List..." : "Lista hozzáadása",
    "New List" : "Új lista",
    "Settings" : "Beállítások",
    "Start of week" : "A hét első napja",
    "Visibility of Smart Collections" : "Okos gyűjtemény láthatósága",
    "Change sort order" : "Rendezési sorrend váltás",
    "Default" : "Alapértelmezett",
    "Due date" : "Lejárati dátum",
    "Start date" : "Kezdő dátum",
    "Priority" : "Prioritás",
    "Alphabetically" : "Betűrendben",
    "Manually" : "Manuálisan",
    "Load remaining completed tasks." : "Hátralévő befejezett feladatok betöltése.",
    "Task is completed" : "Feladat elvégezve",
    "All day" : "Egész napos",
    "(New category)" : "(Új kategória)",
    "Select categories..." : "Kategória kiválasztása...",
    "Loading the task..." : "Feladat betöltése...",
    "Task not found!" : "Feladat nem található!",
    "add a subtask to" : "részfeladat hozzáadás ehhez",
    "Toggle subtasks" : "Alfeladat ki/be kapcsolása",
    "Toggle completed subtasks" : "Teljesített feladatok megjelenítése/elrejtése"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/hu.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Feladatok",
    "Due yesterday" : "Tegnapi teendök",
    "Due today" : "Mai teendök",
    "Due tomorrow" : "Holnapi teendök",
    "Due on" : "Esedékes",
    "Started yesterday" : "Megkezdve tegnap",
    "Starts today" : "Kezdés ma",
    "Starts tomorrow" : "Kezdés holnap",
    "Started on" : "Megkezdve",
    "Starts on" : "Kezdödik",
    "[Remind me yesterday at ]HH:mm" : "[Emlékeztess holnap ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Emlékeztess ma ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Emlékeztess holnap ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Emlékeztess ]MMM DD, YYYY,HH:mm[ kor ]",
    "Yesterday" : "Tegnap",
    "Today" : "Ma",
    "Tomorrow" : "Holnap",
    "in %s" : "itt:  %s",
    "%s ago" : "%s ezelött",
    "seconds" : "másodperc",
    "a minute" : "egy perc",
    "%d minutes" : "%d perc",
    "an hour" : "óra",
    "%d hours" : "%d óra",
    "a day" : "Nap",
    "%d days" : "%d nap",
    "a month" : "egy hónap",
    "%d months" : "%d hónap",
    "a year" : "egy év",
    "%d years" : "%d év",
    "week" : "hét",
    "weeks" : "hetek",
    "day" : "nap",
    "days" : "nap",
    "hour" : "óra",
    "hours" : "óra",
    "minute" : "perc",
    "minutes" : "perc",
    "second" : "másodperc",
    "before beginning" : "kezdés elött",
    "after beginning" : "kezdés után",
    "before end" : "Befejezés elött",
    "after end" : "Befejezés után",
    "Comment" : "Hozzászólás",
    "Add a comment" : "Hozzászólás hozzáadása",
    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "Ez törölni fogja a Naptár \"%s\" és a hozzá kapcsolódó eseményeket és feladatokat.",
    "The name \"%s\" is already used." : "Ez a név \"%s\" már foglalt.",
    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
    "Hidden" : "Rejtett",
    "Visible" : "Látható",
    "Automatic" : "Automatikus",
    "Sunday" : "vasárnap",
    "Monday" : "hétfő",
    "Tuesday" : "kedd",
    "Wednesday" : "szerda",
    "Thursday" : "csütörtök",
    "Friday" : "péntek",
    "Saturday" : "szombat",
    "Add an important item in \"%s\"..." : "Fontos elem hozzáadása ebben: %s...",
    "Add an item due today in \"%s\"..." : "Elem hozzáadása ma ebben: %s...",
    "Add an item in \"%s\"..." : "Elem hozzáadása ebben: %s...",
    "Add a current item in \"%s\"..." : "Jelenlegi elem hozzáadása ebben: %s...",
    "Add a subtask to \"%s\"..." : "Részfeladat hozzáadás ehhez: \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n befejezett feladat","%n befejezett feladat"],
    "Hours" : "Óra",
    "Minutes" : "Perc",
    "Set due date" : "Lejárati dátum beállítása",
    "%s %% completed" : "%s %% befejezve",
    "priority %s: " : "prioritás %s:",
    "high" : "magas",
    "medium" : "közepes",
    "low" : "alacsony",
    "no priority assigned" : "nincs prioritás beállítva",
    "Remind me" : "Emlékeztess",
    "at the end" : "a végénél",
    "at the beginning" : "az elején",
    "Set start date" : "Kezdő dátum beállítása",
    "{calendar} shared by {owner}" : "{calendar} megosztója: {owner}",
    "Unnamed" : "Névtelen",
    "Important" : "Fontos",
    "Week" : "Hét",
    "All" : "Mind",
    "Current" : "Jelenlegi",
    "Completed" : "Befejezve",
    "The Tasks app for Nextcloud" : "Feladatok alkalmazás Nextcloud-hoz",
    "Delete" : "Törlés",
    "Cancel" : "Mégsem",
    "Edit" : "Szerkesztés",
    "Link" : "Hivatkozás",
    "Download" : "Letöltés",
    "Save" : "Mentés",
    "Add List..." : "Lista hozzáadása",
    "New List" : "Új lista",
    "Settings" : "Beállítások",
    "Start of week" : "A hét első napja",
    "Visibility of Smart Collections" : "Okos gyűjtemény láthatósága",
    "Change sort order" : "Rendezési sorrend váltás",
    "Default" : "Alapértelmezett",
    "Due date" : "Lejárati dátum",
    "Start date" : "Kezdő dátum",
    "Priority" : "Prioritás",
    "Alphabetically" : "Betűrendben",
    "Manually" : "Manuálisan",
    "Load remaining completed tasks." : "Hátralévő befejezett feladatok betöltése.",
    "Task is completed" : "Feladat elvégezve",
    "All day" : "Egész napos",
    "(New category)" : "(Új kategória)",
    "Select categories..." : "Kategória kiválasztása...",
    "Loading the task..." : "Feladat betöltése...",
    "Task not found!" : "Feladat nem található!",
    "add a subtask to" : "részfeladat hozzáadás ehhez",
    "Toggle subtasks" : "Alfeladat ki/be kapcsolása",
    "Toggle completed subtasks" : "Teljesített feladatok megjelenítése/elrejtése"
},
"nplurals=2; plural=(n != 1);");
